/**
 * \file
 *         Provides shell commands for configuration
 */

#include "contiki.h"
#include <stdio.h>
#include "serial-shell.h"
#include "shell.h"
#include "dev/serial-line.h"
#include "dev/uart1.h"
#include "route.h"
#include "dev/cc2420.h"
#include "lib/print-stats.h"
#include "dev/leds.h"
#include "dev/watchdog.h"
#include "node-id.h"
#include "ecc.h"

/*---------------------------------------------------------------------------*/
PROCESS(shell_nodeid_process, "nodeid");
SHELL_COMMAND(nodeid_command,
	      "nodeid",
	      "nodeid: set node ID",
	      &shell_nodeid_process);

/*---------------------------------------------------------------------------*/
PROCESS(shell_ecc_process, "ecc");
SHELL_COMMAND(ecc_command,
	      "ecc",
	      "ecc: test ecc codec functionality",
	      &shell_ecc_process);

/*---------------------------------------------------------------------------*/
PROCESS_THREAD(shell_nodeid_process, ev, data)
{
  uint16_t nodeid;
  char buf[20];
  const char *newptr;
  PROCESS_BEGIN();

  nodeid = shell_strtolong(data, &newptr);

  /* If no node ID was given on the command line, we print out the
     current channel. Else we burn the new node ID. */
  if(newptr == data) {
    nodeid = node_id;
  } else {
    nodeid = shell_strtolong(data, &newptr);
    if (nodeid != node_id) {
		watchdog_stop();
		leds_on(LEDS_RED);
		node_id_burn(nodeid);
		leds_on(LEDS_BLUE);
		node_id_restore();
		leds_off(LEDS_RED + LEDS_BLUE);
		watchdog_start();
    }
  }

  snprintf(buf, sizeof(buf), "%d", nodeid);
  shell_output_str(&nodeid_command, "Node ID: ", buf);

  PROCESS_END();
}


/*---------------------------------------------------------------------------*/
PROCESS_THREAD(shell_ecc_process, ev, data)
{
  PROCESS_BEGIN();
  printf("ecc command: testing ecc codecs\n");
  ECC_run_test_program();
  PROCESS_END();
}


/*---------------------------------------------------------------------------*/
void
fec_shell_init(void)
{

	uart1_set_input(serial_line_input_byte);
	serial_line_init();
	serial_shell_init();


	shell_register_command(&nodeid_command);
	shell_register_command(&ecc_command);
}
